diff --git a/src/yuzu/aboutdialog.ui b/src/yuzu/aboutdialog.ui
index 107fa8e95d..3b2ca649d9 100644
--- a/src/yuzu/aboutdialog.ui
+++ b/src/yuzu/aboutdialog.ui
@@ -1,4 +1,5 @@
+
AboutDialog
@@ -11,7 +12,7 @@
- About yuzu
+ About suyu
-
@@ -69,7 +70,7 @@
- <html><head/><body><p><span style=" font-size:28pt;">Suyu</span></p></body></html>
+ <html><head/><body><p><span style=" font-size:28pt;">suyu</span></p></body></html>
@@ -99,9 +100,9 @@
<html><head><meta name="qrichtext" content="1" /><style type="text/css">
p, li { white-space: pre-wrap; }
</style></head><body style=" font-family:'Ubuntu'; font-size:11pt; font-weight:400; font-style:normal;">
-<p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:'MS Shell Dlg 2'; font-size:12pt;">Suyu is an experimental open-source emulator for the Nintendo Switch licensed under GPLv3.0+.</span></p>
+<p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:'MS Shell Dlg 2'; font-size:12pt;">suyu is a continuation of an experimental open-source emulator for the Nintendo Switch licensed under GPLv3.0+.</span></p>
<p style="-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:'MS Shell Dlg 2'; font-size:8pt;"><br /></p>
-<p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:'MS Shell Dlg 2'; font-size:12pt;">This software should not be used to play games you have not legally obtained.</span></p></body></html>
+<p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:'MS Shell Dlg 2'; font-size:12pt;">This software should not be used to play games you have not legally obtained. No support will be provided if you have not legally obtained your game dumps.</span></p></body></html>
Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter
@@ -127,7 +128,7 @@ p, li { white-space: pre-wrap; }
-
- <html><head/><body><p><a href="https://gitlab.com/suyu-emu/suyu"><span style=" text-decoration: underline; color:#039be5;">Website</span></a> | <a href="https://discord.com/invite/2gQRBp44KT"><span style=" text-decoration: underline; color:#039be5;">Discord</span></a> | <a href="https://gitlab.com/suyu-emu/suyu"><span style=" text-decoration: underline; color:#039be5;">Source Code</span></a> | <a href="https://gitlab.com/suyu-emu/suyu/-/graphs/master"><span style=" text-decoration: underline; color:#039be5;">Contributors</span></a> | <a href="https://gitlab.com/suyu-emu/suyu/-/blob/master/LICENSE.txt"><span style=" text-decoration: underline; color:#039be5;">License</span></a></p></body></html>
+ <html><head/><body><p><a href="https://suyu.dev/"><span style=" text-decoration: underline; color:#039be5;">Website</span></a> | <a href="https://gitlab.com/suyu-emu/suyu"><span style=" text-decoration: underline; color:#039be5;">Source Code</span></a> | <a href="https://gitlab.com/suyu-emu/suyu/-/project_members"><span style=" text-decoration: underline; color:#039be5;">Contributors</span></a> | <a href="https://gitlab.com/suyu-emu/suyu/-/blob/dev/LICENSE.txt"><span style=" text-decoration: underline; color:#039be5;">License</span></a></p></body></html>
true
@@ -143,7 +144,7 @@ p, li { white-space: pre-wrap; }
- <html><head/><body><p><span style=" font-size:7pt;">"Nintendo Switch" is a trademark of Nintendo. Suyu is not affiliated with Nintendo in any way.</span></p></body></html>
+ <html><head/><body><p><span style=" font-size:7pt;">"Nintendo Switch" is a trademark of Nintendo. suyu is not affiliated with Nintendo in any way.</span></p></body></html>
@@ -164,6 +165,7 @@ p, li { white-space: pre-wrap; }
+
@@ -172,32 +174,12 @@ p, li { white-space: pre-wrap; }
accepted()
AboutDialog
accept()
-
-
- 20
- 20
-
-
- 20
- 20
-
-
buttonBox
rejected()
AboutDialog
reject()
-
-
- 20
- 20
-
-
- 20
- 20
-
-
-
+
\ No newline at end of file
diff --git a/src/yuzu/main.ui b/src/yuzu/main.ui
index bcc892672f..c9d6625836 100644
--- a/src/yuzu/main.ui
+++ b/src/yuzu/main.ui
@@ -1,4 +1,5 @@
+
MainWindow
@@ -376,7 +377,7 @@
- Open &yuzu Folder
+ Open &suyu Folder
diff --git a/src/yuzu/main.cpp b/src/yuzu/main.cpp
index 63994424e5..eb9214d245 100644
--- a/src/yuzu/main.cpp
+++ b/src/yuzu/main.cpp
@@ -1,7 +1,7 @@
// SPDX-FileCopyrightText: 2014 Citra Emulator Project & 2024 suyu Emulator Project
// SPDX-License-Identifier: GPL-2.0-or-later
-// Modified by palfaiate on <2024/03/07>
+// Modified by KawaiiBunga on <2024/03/07>
#include
#include
@@ -201,8 +201,8 @@ void GMainWindow::ShowTelemetryCallout() {
UISettings::values.callout_flags =
UISettings::values.callout_flags.GetValue() | static_cast(CalloutFlag::Telemetry);
const QString telemetry_message =
- tr("Anonymous "
- "data is collected to help improve yuzu. "
+ tr("Anonymous "
+ "data is collected to help improve suyu. "
"
Would you like to share your usage data with us?");
if (!question(this, tr("Telemetry"), telemetry_message)) {
Settings::values.enable_telemetry = false;
@@ -436,7 +436,7 @@ GMainWindow::GMainWindow(std::unique_ptr config_, bool has_broken_vulk
QMessageBox::warning(this, tr("Broken Vulkan Installation Detected"),
tr("Vulkan initialization failed during boot.
Click "
"here for instructions to fix the issue."));
@@ -458,7 +458,7 @@ GMainWindow::GMainWindow(std::unique_ptr config_, bool has_broken_vulk
// Set a screensaver inhibition reason string. Currently passed to DBus by SDL and visible to
// the user through their desktop environment.
//: TRANSLATORS: This string is shown to the user to explain why yuzu needs to prevent the
//: computer from sleeping
QByteArray wakelock_reason = tr("Running a game").toUtf8();
SDL_SetHint(SDL_HINT_SCREENSAVER_INHIBIT_ACTIVITY_NAME, wakelock_reason.data());
@@ -1804,8 +1804,8 @@ bool GMainWindow::LoadROM(const QString& filename, Service::AM::FrontendAppletPa
tr("You are using the deconstructed ROM directory format for this game, which is an "
"outdated format that has been superseded by others such as NCA, NAX, XCI, or "
"NSP. Deconstructed ROM directories lack icons, metadata, and update "
- "support.
For an explanation of the various Switch formats yuzu supports, check out our "
+ "support.
For an explanation of the various Switch formats suyu supports, check out our "
"wiki. This message will not be shown again."));
}
@@ -1819,11 +1819,11 @@ bool GMainWindow::LoadROM(const QString& filename, Service::AM::FrontendAppletPa
case Core::SystemResultStatus::ErrorVideoCore:
QMessageBox::critical(
this, tr("An error occurred initializing the video core."),
- tr("yuzu has encountered an error while running the video core. "
+ tr("suyu has encountered an error while running the video core. "
"This is usually caused by outdated GPU drivers, including integrated ones. "
"Please see the log for more details. "
"For more information on accessing the log, please see the following page: "
- ""
+ ""
"How to Upload the Log File. "));
break;
default:
@@ -1837,9 +1837,9 @@ bool GMainWindow::LoadROM(const QString& filename, Service::AM::FrontendAppletPa
tr("Error while loading ROM! %1", "%1 signifies a numeric error code.")
.arg(QString::fromStdString(error_code));
const auto description =
- tr("%1
Please follow the "
- "yuzu quickstart guide to redump your files.
You can refer "
- "to the yuzu wiki or the yuzu Discord for help.",
+ tr("%1
Please follow the "
+ "suyu quickstart guide to redump your files.
You can refer "
+ "to the suyu wiki or the suyu Discord for help.",
"%1 signifies an error string.")
.arg(QString::fromStdString(
GetResultStatusString(static_cast(error_id))));
@@ -1914,7 +1914,7 @@ void GMainWindow::ConfigureFilesystemProvider(const std::string& filepath) {
void GMainWindow::BootGame(const QString& filename, Service::AM::FrontendAppletParameters params,
StartGameType type) {
- LOG_INFO(Frontend, "yuzu starting...");
+ LOG_INFO(Frontend, "suyu starting...");
if (params.program_id == 0 ||
params.program_id > static_cast(Service::AM::AppletProgramId::MaxProgramId)) {
@@ -2654,7 +2654,7 @@ void GMainWindow::OnGameListNavigateToGamedbEntry(u64 program_id,
directory = it->second.second;
}
- QDesktopServices::openUrl(QUrl(QStringLiteral("https://yuzu-emu.org/game/") + directory));
+ QDesktopServices::openUrl(QUrl(QStringLiteral("https://suyu.dev/game/") + directory));
}
bool GMainWindow::CreateShortcutLink(const std::filesystem::path& shortcut_path,
@@ -2792,7 +2792,7 @@ bool GMainWindow::CreateShortcutMessagesGUI(QWidget* parent, int imsg, const QSt
bool GMainWindow::MakeShortcutIcoPath(const u64 program_id, const std::string_view game_file_name,
std::filesystem::path& out_icon_path) {
// Get path to Yuzu icons directory & icon extension
std::string ico_extension = "png";
#if defined(_WIN32)
out_icon_path = Common::FS::GetSuyuPath(Common::FS::SuyuPath::IconsDir);
@@ -2819,7 +2819,7 @@ bool GMainWindow::MakeShortcutIcoPath(const u64 program_id, const std::string_vi
void GMainWindow::OnGameListCreateShortcut(u64 program_id, const std::string& game_path,
GameListShortcutTarget target) {
// Get path to yuzu executable
const QStringList args = QApplication::arguments();
std::filesystem::path yuzu_command = args[0].toStdString();
// If relative path, make it an absolute path
@@ -2900,7 +2900,7 @@ void GMainWindow::OnGameListCreateShortcut(u64 program_id, const std::string& ga
this, GMainWindow::CREATE_SHORTCUT_MSGBOX_FULLSCREEN_YES, qt_game_title)) {
arguments = "-f " + arguments;
}
- const std::string comment = fmt::format("Start {:s} with the yuzu Emulator", game_title);
+ const std::string comment = fmt::format("Start {:s} with the suyu Emulator", game_title);
const std::string categories = "Game;Emulator;Qt;";
const std::string keywords = "Switch;Nintendo;";
@@ -3370,9 +3370,9 @@ void GMainWindow::OnMenuReportCompatibility() {
compatdb.exec();
} else {
QMessageBox::critical(
- this, tr("Missing yuzu Account"),
- tr("In order to submit a game compatibility test case, you must link your yuzu "
- "account.
To link your yuzu account, go to Emulation > Configuration "
+ this, tr("Missing suyu Account"),
+ tr("In order to submit a game compatibility test case, you must link your suyu "
+ "account.
To link your suyu account, go to Emulation > Configuration "
"> "
"Web."));
}
@@ -3392,15 +3392,15 @@ void GMainWindow::OpenURL(const QUrl& url) {
}
void GMainWindow::OnOpenModsPage() {
- OpenURL(QUrl(QStringLiteral("https://github.com/yuzu-emu/yuzu/wiki/Switch-Mods")));
+ OpenURL(QUrl(QStringLiteral("https://suyu.dev")));
}
void GMainWindow::OnOpenQuickstartGuide() {
- OpenURL(QUrl(QStringLiteral("https://yuzu-emu.org/help/quickstart/")));
+ OpenURL(QUrl(QStringLiteral("https://gitlab.com/suyu-emu/suyu/-/wikis/wiki/Quickstart")));
}
void GMainWindow::OnOpenFAQ() {
- OpenURL(QUrl(QStringLiteral("https://yuzu-emu.org/wiki/faq/")));
+ OpenURL(QUrl(QStringLiteral("https://gitlab.com/suyu-emu/suyu/-/wikis/wiki/FAQ")));
}
void GMainWindow::ToggleFullscreen() {
@@ -3976,7 +3976,7 @@ void GMainWindow::OnInstallFirmware() {
if (!ContentManager::AreKeysPresent()) {
QMessageBox::information(
this, tr("Keys not installed"),
- tr("Install decryption keys and restart yuzu before attempting to install firmware."));
+ tr("Install decryption keys and restart suyu before attempting to install firmware."));
return;
}
@@ -4066,7 +4066,7 @@ void GMainWindow::OnInstallFirmware() {
QMessageBox::warning(
this, tr("Firmware install failed"),
tr("Firmware installation cancelled, firmware may be in bad state, "
- "restart yuzu or re-install firmware."));
+ "restart suyu or re-install firmware."));
return;
}
}
@@ -4602,7 +4602,7 @@ void GMainWindow::OnCheckFirmwareDecryption() {
QMessageBox::warning(
this, tr("Derivation Components Missing"),
tr("Encryption keys are missing. "
- "
Please follow the yuzu "
+ "
Please follow the suyu "
"quickstart guide to get all your keys, firmware and "
"games."));
}
@@ -4657,8 +4657,8 @@ bool GMainWindow::ConfirmClose() {
UISettings::values.confirm_before_stopping.GetValue() == ConfirmStop::Ask_Based_On_Game) {
return true;
}
- const auto text = tr("Are you sure you want to close yuzu?");
- return question(this, tr("yuzu"), text);
+ const auto text = tr("Are you sure you want to close suyu?");
+ return question(this, tr("suyu"), text);
}
void GMainWindow::closeEvent(QCloseEvent* event) {
@@ -4738,7 +4738,7 @@ bool GMainWindow::ConfirmChangeGame() {
// Use custom question to link controller navigation
return question(
- this, tr("yuzu"),
+ this, tr("suyu"),
tr("Are you sure you want to stop the emulation? Any unsaved progress will be lost."),
QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
}
@@ -4747,10 +4747,10 @@ bool GMainWindow::ConfirmForceLockedExit() {
if (emu_thread == nullptr) {
return true;
}
- const auto text = tr("The currently running application has requested yuzu to not exit.\n\n"
+ const auto text = tr("The currently running application has requested suyu to not exit.\n\n"
"Would you like to bypass this and exit anyway?");
- return question(this, tr("yuzu"), text);
+ return question(this, tr("suyu"), text);
}
void GMainWindow::RequestGameExit() {
@@ -5027,8 +5027,8 @@ int main(int argc, char* argv[]) {
Common::ConfigureNvidiaEnvironmentFlags();
// Init settings params
- QCoreApplication::setOrganizationName(QStringLiteral("yuzu team"));
- QCoreApplication::setApplicationName(QStringLiteral("yuzu"));
+ QCoreApplication::setOrganizationName(QStringLiteral("suyu team"));
+ QCoreApplication::setApplicationName(QStringLiteral("suyu"));
#ifdef _WIN32
// Increases the maximum open file limit to 8192
@@ -458,7 +458,7 @@ GMainWindow::GMainWindow(std::unique_ptr config_, bool has_broken_vulk
// Set a screensaver inhibition reason string. Currently passed to DBus by SDL and visible to
// the user through their desktop environment.
- //: TRANSLATORS: This string is shown to the user to explain why yuzu needs to prevent the
+ //: TRANSLATORS: This string is shown to the user to explain why suyu needs to prevent the
//: computer from sleeping
QByteArray wakelock_reason = tr("Running a game").toUtf8();
@@ -2792,7 +2792,7 @@ bool GMainWindow::CreateShortcutMessagesGUI(QWidget* parent, int imsg, const QSt
bool GMainWindow::MakeShortcutIcoPath(const u64 program_id, const std::string_view game_file_name,
std::filesystem::path& out_icon_path) {
- // Get path to Yuzu icons directory & icon extension
+ // Get path to suyu icons directory & icon extension
std::string ico_extension = "png";
#if defined(_WIN32)
@@ -2819,7 +2819,7 @@ bool GMainWindow::MakeShortcutIcoPath(const u64 program_id, const std::string_vi
void GMainWindow::OnGameListCreateShortcut(u64 program_id, const std::string& game_path,
GameListShortcutTarget target) {
- // Get path to yuzu executable
+ // Get path to suyu executable
const QStringList args = QApplication::arguments();
std::filesystem::path yuzu_command = args[0].toStdString();